/*
 * Purple - Internet Messaging Library
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Purple is the legal property of its developers, whose names are too numerous
 * to list here. Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PURPLE_GLOBAL_HEADER_INSIDE) && !defined(PURPLE_COMPILATION)
# error "only <purple.h> may be included directly"
#endif

#ifndef PURPLE_ACCOUNT_PRIVATE_H
#define PURPLE_ACCOUNT_PRIVATE_H

#include <glib.h>

#include "purpleaccount.h"
#include "xmlnode.h"

G_BEGIN_DECLS

/**
 * _purple_account_to_xmlnode: (skip)
 * @account:  The account
 *
 * Get an XML description of an account.
 *
 * Returns:  The XML description of the account.
 */
G_GNUC_INTERNAL
PurpleXmlNode *_purple_account_to_xmlnode(PurpleAccount *account);

/**
 * purple_account_set_enabled_plain: (skip)
 * @account: The instance.
 * @enabled: Whether or not the account is enabled.
 *
 * This is a temporary method until we overhaul serialization of accounts.
 *
 * This method sets the enabled state of an account without any side effects.
 * Its primary usage is when loading accounts from disk, as without this, the
 * account attempts to connect immediately.
 *
 * Since: 3.0
 */
G_GNUC_INTERNAL
void purple_account_set_enabled_plain(PurpleAccount *account, gboolean enabled);

G_END_DECLS

#endif /* PURPLE_ACCOUNT_PRIVATE_H */
