/*
 * Purple - Internet Messaging Library
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Purple is the legal property of its developers, whose names are too numerous
 * to list here. Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PURPLE_GLOBAL_HEADER_INSIDE) && !defined(PURPLE_COMPILATION)
# error "only <purple.h> may be included directly"
#endif

#ifndef PURPLE_HISTORY_ADAPTER_PRIVATE_H
#define PURPLE_HISTORY_ADAPTER_PRIVATE_H

#include <glib.h>

#include "purpleversion.h"

G_BEGIN_DECLS

/**
 * purple_history_adapter_activate: (skip)
 * @adapter: The #PurpleHistoryAdapter instance.
 * @error: A return address for a #GError.
 *
 * Asks @adapter to become the active adapter. If @adapter can not become active
 * it should return %FALSE and set @error.
 *
 * NOTE: This is public only for tests. Do not use outside of libpurple.
 *
 * Returns: %TRUE on success otherwise %FALSE with @error set.
 *
 * Since: 3.0
 */
PURPLE_AVAILABLE_IN_3_0
gboolean purple_history_adapter_activate(PurpleHistoryAdapter *adapter, GError **error);

/**
 * purple_history_adapter_deactivate: (skip)
 * @adapter: The #PurpleHistoryAdapter instance.
 * @error: A return address for a #GError.
 *
 * Asks @adapter to stop being the active adapter. If @adapter can not
 * deactivate it should return %FALSE and set @error.
 *
 * NOTE: This is public only for tests. Do not use outside of libpurple.
 *
 * Returns: %TRUE on success otherwise %FALSE with @error set.
 *
 * Since: 3.0
 */
PURPLE_AVAILABLE_IN_3_0
gboolean purple_history_adapter_deactivate(PurpleHistoryAdapter *adapter, GError **error);

G_END_DECLS

#endif /* PURPLE_HISTORY_ADAPTER_PRIVATE_H */
