/*
 * Pidgin - Internet Messenger
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Pidgin is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PIDGIN_GLOBAL_HEADER_INSIDE) && !defined(PIDGIN_COMPILATION)
# error "only <pidgin.h> may be included directly"
#endif

#ifndef PIDGIN_CONVERSATION_MEMBER_H
#define PIDGIN_CONVERSATION_MEMBER_H

#include <gtk/gtk.h>

#include <purple.h>

#include "pidginversion.h"

G_BEGIN_DECLS

/**
 * PidginConversationMember:
 *
 * A widget that is used to display a conversation member.
 *
 * Since: 3.0
 */

#define PIDGIN_TYPE_CONVERSATION_MEMBER (pidgin_conversation_member_get_type())

PIDGIN_AVAILABLE_IN_3_0
G_DECLARE_FINAL_TYPE(PidginConversationMember, pidgin_conversation_member,
                     PIDGIN, CONVERSATION_MEMBER, GtkBox)

/**
 * pidgin_conversation_member_new:
 * @conversation_member: the conversation member to display
 *
 * Creates a display for a conversation member.
 *
 * Returns: (transfer full) (type PidginConversationMember): The conversation
 *          member display.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
GtkWidget *pidgin_conversation_member_new(PurpleConversationMember *conversation_member);

/**
 * pidgin_conversation_member_get_conversation_member:
 *
 * Gets the currently displayed conversation member.
 *
 * Returns: (transfer none): The [type@Purple.ConversationMember] that is
 *          currently displayed.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
PurpleConversationMember *pidgin_conversation_member_get_conversation_member(PidginConversationMember *member);

/**
 * pidgin_conversation_member_set_conversation_member:
 * @conversation_member: (nullable): the new conversation member to display
 *
 * Sets the currently displayed conversation member.
 *
 * Since: 3.0
 */
PIDGIN_AVAILABLE_IN_3_0
void pidgin_conversation_member_set_conversation_member(PidginConversationMember *member, PurpleConversationMember *conversation_member);

G_END_DECLS

#endif /* PIDGIN_CONVERSATION_MEMBER_H */
