/*
 * Pidgin - Internet Messenger
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Pidgin is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 */

#include "pidginiconname.h"

/******************************************************************************
 * Public API
 *****************************************************************************/
const char *
pidgin_icon_name_from_presence_primitive(PurplePresencePrimitive primitive,
                                         const char *fallback)
{
	switch(primitive) {
	case PURPLE_PRESENCE_PRIMITIVE_OFFLINE:
		return "pidgin-user-offline";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_AVAILABLE:
		return "pidgin-user-available";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_IDLE:
		return "pidgin-user-unavailable";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_INVISIBLE:
		return "pidgin-user-invisible";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_AWAY:
		return "pidgin-user-away";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_DO_NOT_DISTURB:
		return "pidgin-user-do-not-disturb";
		break;
	case PURPLE_PRESENCE_PRIMITIVE_STREAMING:
		/* TODO: get an icon for streaming. */
	default:
		break;
	}

	return fallback;
}

const char *
pidgin_icon_name_from_presence(PurplePresence *presence, const char *fallback)
{
	if(PURPLE_IS_PRESENCE(presence)) {
		PurplePresencePrimitive primitive;

		primitive = purple_presence_get_primitive(presence);

		return pidgin_icon_name_from_presence_primitive(primitive, fallback);
	}

	return fallback;
}
