/*
 * Pidgin - Internet Messenger
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Pidgin is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 */

#include <glib/gi18n-lib.h>

#include <purple.h>

#include <adwaita.h>

#include "pidgindeveloperprefs.h"
#include "pidgincore.h"

struct _PidginDeveloperPrefs {
	AdwPreferencesPage parent;

	GtkWidget *developer_mode;
};

G_DEFINE_FINAL_TYPE(PidginDeveloperPrefs, pidgin_developer_prefs,
                    ADW_TYPE_PREFERENCES_PAGE)

/******************************************************************************
 * GObject Implementation
 *****************************************************************************/
static void
pidgin_developer_prefs_class_init(PidginDeveloperPrefsClass *klass) {
	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);

	gtk_widget_class_set_template_from_resource(widget_class,
	                                            "/im/pidgin/Pidgin3/Prefs/developer.ui");

	gtk_widget_class_bind_template_child(widget_class, PidginDeveloperPrefs,
	                                     developer_mode);
}

static void
pidgin_developer_prefs_init(PidginDeveloperPrefs *prefs) {
	GSettings *settings = NULL;

	gtk_widget_init_template(GTK_WIDGET(prefs));

	settings = purple_core_new_settings("im.pidgin.Purple.Core");
	g_settings_bind(settings, "developer-mode",
	                prefs->developer_mode, "active",
	                G_SETTINGS_BIND_DEFAULT);
	g_clear_object(&settings);
}

/******************************************************************************
 * API
 *****************************************************************************/
GtkWidget *
pidgin_developer_prefs_new(void) {
	return g_object_new(PIDGIN_TYPE_DEVELOPER_PREFS, NULL);
}
